@@ -47,7 +47,7 @@ class ErrorInfo(Error):
     name = "no-path-join"
     enabled = False
     code = 147
-    categories = ["pathlib"]
+    categories = ("pathlib",)
 
 
 def check(node: CallExpr, errors: list[Error]) -> None:
